All of lore.kernel.org
 help / color / mirror / Atom feed
From: Robert Hancock <hancockrwd@gmail.com>
To: linux-kernel <linux-kernel@vger.kernel.org>, lm-sensors@lm-sensors.org
Cc: r.marek@assembler.cz
Subject: [lm-sensors] [PATCH] coretemp: add support for Core i5 CPU
Date: Sun, 20 Sep 2009 18:19:54 +0000	[thread overview]
Message-ID: <4AB6724A.1060702@gmail.com> (raw)
In-Reply-To: <4AB5DE1F.1020004@gmail.com>

Add coretemp support for Core i5 (Lynnfield) CPUs with model 0x1E.

Signed-off-by: Robert Hancock <hancockrwd@gmail.com>

---

This minimal patch works to add support for these CPUs, though we should likely
still look into using the CPUID flags instead of the model check.

diff --git a/drivers/hwmon/coretemp.c b/drivers/hwmon/coretemp.c
index 93c1722..a9a21dc 100644
--- a/drivers/hwmon/coretemp.c
+++ b/drivers/hwmon/coretemp.c
@@ -413,11 +413,11 @@ static int __init coretemp_init(void)
 	for_each_online_cpu(i) {
 		struct cpuinfo_x86 *c = &cpu_data(i);
 
 		/* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1A */
 		if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
 		    !((c->x86_model = 0xe) || (c->x86_model = 0xf) ||
 			(c->x86_model = 0x16) || (c->x86_model = 0x17) ||
-			(c->x86_model = 0x1A))) {
+			(c->x86_model = 0x1A) || (c->x86_model = 0x1E))) {
 
 			/* supported CPU not found, but report the unknown
 			   family 6 CPU */

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

WARNING: multiple messages have this Message-ID (diff)
From: Robert Hancock <hancockrwd@gmail.com>
To: linux-kernel <linux-kernel@vger.kernel.org>, lm-sensors@lm-sensors.org
Cc: r.marek@assembler.cz
Subject: [PATCH] coretemp: add support for Core i5 CPU
Date: Sun, 20 Sep 2009 12:19:54 -0600	[thread overview]
Message-ID: <4AB6724A.1060702@gmail.com> (raw)
In-Reply-To: <4AB5DE1F.1020004@gmail.com>

Add coretemp support for Core i5 (Lynnfield) CPUs with model 0x1E.

Signed-off-by: Robert Hancock <hancockrwd@gmail.com>

---
@@ -413,11 +413,11 @@ static int __init coretemp_init(void)
 		struct cpuinfo_x86 *c = &cpu_data(i);
 
-		/* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1A */
+		/* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1A, 0x1E */
 		if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
 		    !((c->x86_model = 0xe) || (c->x86_model = 0xf) ||

This minimal patch works to add support for these CPUs, though we should likely
still look into using the CPUID flags instead of the model check.

diff --git a/drivers/hwmon/coretemp.c b/drivers/hwmon/coretemp.c
index 93c1722..a9a21dc 100644
--- a/drivers/hwmon/coretemp.c
+++ b/drivers/hwmon/coretemp.c
@@ -413,11 +413,11 @@ static int __init coretemp_init(void)
 	for_each_online_cpu(i) {
 		struct cpuinfo_x86 *c = &cpu_data(i);
 
 		/* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1A */
 		if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
 		    !((c->x86_model == 0xe) || (c->x86_model == 0xf) ||
 			(c->x86_model == 0x16) || (c->x86_model == 0x17) ||
-			(c->x86_model == 0x1A))) {
+			(c->x86_model == 0x1A) || (c->x86_model == 0x1E))) {
 
 			/* supported CPU not found, but report the unknown
 			   family 6 CPU */
@@ -413,11 +413,11 @@ static int __init coretemp_init(void)
 		struct cpuinfo_x86 *c = &cpu_data(i);
 
-		/* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1A */
+		/* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1A, 0x1E */
 		if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
 		    !((c->x86_model == 0xe) || (c->x86_model == 0xf) ||

  reply	other threads:[~2009-09-20 18:19 UTC|newest]

Thread overview: 11+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2009-09-20  7:47 [lm-sensors] coretemp support for Core i5 CPU Robert Hancock
2009-09-20  7:47 ` Robert Hancock
2009-09-20 18:19 ` Robert Hancock [this message]
2009-09-20 18:19   ` [PATCH] coretemp: add " Robert Hancock
2009-09-23 21:19   ` Jean Delvare
2009-09-20 19:16 ` [lm-sensors] coretemp " Jean Delvare
2009-09-20 19:16   ` Jean Delvare
2009-09-20 22:53   ` Robert Hancock
2009-09-20 22:53     ` Robert Hancock
2009-09-21  7:50     ` Jean Delvare
2009-09-21  7:50       ` Jean Delvare

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=4AB6724A.1060702@gmail.com \
    --to=hancockrwd@gmail.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=lm-sensors@lm-sensors.org \
    --cc=r.marek@assembler.cz \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.